#!/usr/bin/perl
use lib '/home/zhidongx/threadom';
use CGI ':standard';
use GD::Graph::lines;
use strict;
use DomainHelper;
use Getopt::Long;

my $operating_system=$^O;
unless ($operating_system eq "linux"){
	printf("Your operating system $operating_system is unsupported at this time\n");
	printf("Currently only Linux is supported\n");
	exit();
}

my ($seqname,$datadir,$cutoffs);
GetOptions('seqname:s' => \$seqname, 'datadir:s' => \$datadir,'cutoffs:s' => \$cutoffs);

if(!$seqname || !$datadir )
{
	printf "drawdc USAGE:\n";
	printf "Mandatory arguments:\n";
	printf "./drawds.pl -seqname sequence_name -datadir dir_name\n";
	printf "Optional arguments whose default values have been set in the config.ini of this package.\n";
	printf "User can also replace the default values in the config file,like:\n";
#	printf "      -datadir datadirectory: the Data_path item in the config.ini\n";
	printf "      -cutoff  \"ce cm ch \"; ce: cutoff value of easy,\tcm :cutoff value of medium;\tch:cutoff value of hard\n";
	
   exit();
}


my $helper       = new DomainHelper();
my %CONFIG       = $helper->readConfig();
my $dataset_name = $CONFIG{'DATASET_NAME'};
my $threadom_path = $CONFIG{'THREADOM_PATH'};
my $dataset_path  = $CONFIG{'DATA_PATH'};  #where input/output files are
my $cutoff_values = $CONFIG{'CUTOFFS'};

#########set domain parser enviroment  ###############



if($datadir){
	$dataset_path=$datadir;
}

if($cutoffs){
$cutoff_values=$cutoffs;
}

my ($ce,$cm,$ch);
$cutoff_values =~ /(\S+)\s+(\S+)\s+(\S+)/;
$ce=$1;
$cm=$2;
$ch=$3;

my $s=$seqname;

if(not -s "$dataset_path/$s.score"){
   print "The domain conservation score file does not exist:$dataset_path/$s.score\n";
   exit();
}
my $score=`cat $dataset_path/$s.score`;
chop($score);
my @array=split('\s',$score);
my (@x,@cutoff,@data);
my $Lch=$#array;

my $max=(int($Lch/10)+1)*10;

open(RD,"<$dataset_path/init.dat");
my $line=<RD>;

chop($line);
$line=~ /(\S+)\s+(\S+)\s+(\S+)\s+(\S+)/;
my $type=$2;
`echo $line > "$dataset_path/$s.type"`;
my $cut=0.6;
if($type eq 'hard'){
  $cut=$ch;
}elsif($type eq 'medm'){
  $cut=$cm;
}else{
  $cut=$ce;
}

for(my $i=0;$i<=$#array;$i++){
   $array[$i]=0 if($array[$i]<0);
  # $array[$i]/=50;
   $x[$i]=$i+1;
   $cutoff[$i]=$cut;
}
for(my $i=$#array+1;$i<$max;$i++){
  $x[$i]=$i+1;
  #$array[$i]=0.0;
  $cutoff[$i]=$cut;
}
push @data,[@x];
push @data,[@array];
push @data,[@cutoff];
my $mygraph = GD::Graph::lines->new( 500, 300 );
$mygraph->set(
    x_label => 'Residue Number',
    y_label => 'Domain Conservation Score',
    title   => "Domain Conservation Score of $s",
    l_margin=>10,
    r_margin=>10,
    t_margin=>10,
    line_types=>[1,2],
    x_min_value => 0,
    x_max_value => $max,
    x_tick_number =>10,
    x_label_skip =>2,
    x_plot_values=>1,
   # x_label_position=>0.5,
    y_min_value => 0.0,
    y_max_value =>1.2,
    y_tick_number =>6,
    y_label_skip=>1,
    #x_labels_vertical=>1
) or warn $mygraph->error;
$mygraph->set_legend_font(GD::gdMediumBoldFont);
$mygraph->set_legend('Score', 'Cutoff');

my $myimage = $mygraph->plot( \@data ) or die $mygraph->error;

open(IMG,">$dataset_path/$s.png");
binmode IMG;
print IMG $myimage->png;
close(IMG);

